
from pyroute2.netlink.iproute import IPRSocket
from pyroute2.netlink.iproute import IPRoute
from pyroute2.netlink.ipdb import IPDB
from pyroute2.netlink.taskstats import TaskStats
from pyroute2.iocore.iocore import IOCore

make_pep8_happy = IPRSocket
make_pep8_happy = IPRoute
make_pep8_happy = IPDB
make_pep8_happy = TaskStats
make_pep8_happy = IOCore
